defmodule ElixirRss.Fetcher do
  def fetch_model(url) do
    url
    |> fetch()
    |> elem(1)
    |> parse_rss_to_model()
  end

  def fetch(url) do
    url
    |> HTTPoison.get()
    |> handle_response()
  end

  defp handle_response({:ok, %{status_code: 200, body: body}}) do
    {:ok, body}
  end
  defp handle_response({_, %{status_code: _, body: body}}) do
    {:error, body}
  end

  def parse_rss_to_model(rss_xml) do
    rss_xml
    |> FastRSS.parse_rss()
    |> elem(1)
    |> Map.get("items")
    |> Enum.map(fn item ->
      Map.take(item, ["title", "description"])
    end)
  end
end
